@@ -27,7 +27,7 @@ class DataNode(DatasetManager):
             description = f"data {name}"
             
         name = f'{name}.parquet'
-        replace = self._check_fileExists(directory, name)
+        replace = self._check_fileExists(directory, name) if replace == None else replace
         
         _res = requests.post(f'{self._discovery_api}/file/', headers=self._jwt_header,
                                 json={
@@ -150,7 +150,17 @@ from sqlalchemy import sql
             return pd.read_csv(f"s3://{bucket_name}/{meta['key']}", storage_options=self._storage_options)
         return Exception(f"Can not read file extension {_f_type}, support [parquet, csv]")
     
-    
+    def get_file_id(self, name=None, directory_id=None):
+        check.check_type(variable=name, variableName="name", dtype=str)
+        check.check_type(variable=directory_id, variableName="directory_id", dtype=int)
+        r = requests.post(f"{self._discovery_api}/file/get-file-id/", headers=self._jwt_header, 
+                          json={
+                              'name': name,
+                              'directory': directory_id
+                          }
+        )
+        check_http_status_code(r)
+        return r.json().get('id')
 class DatabaseManagement(Base):
     def _get_connection_str(self, con_id=None):
         '''Get sqlalchemy connection string
