@@ -4,9 +4,10 @@ from tqdm.auto import tqdm
 from tqdm.utils import CallbackIOWrapper
 
 from .base import Base
+from .utils import check
 class DatasetManager(Base):
 
-    def upload_file(self, directory_id=None, file_path=None, description=""):
+    def upload_file(self, directory_id=None, file_path=None, description="", lineage=None):
         if type(file_path) != str :
             raise Exception(f"file_path expect `str` but got {type(file_path)}, or please input `file_path='<path>'`")
         elif not os.path.exists(file_path):
@@ -16,12 +17,17 @@ class DatasetManager(Base):
         _res = requests.get(f"{self._discovery_api}/directory/{directory_id}",  headers=self._jwt_header)
         if _res.status_code == 404:
             raise Exception(f"directory {directory_id} not found or your dose not has permission to access directory")
+        
         f_name = os.path.basename(file_path)
         replace = self._check_fileExists(directory_id, f_name)
+        
+        if description == "":
+            description = f"file {f_name}"
+            
         _res = requests.post(f"{self._discovery_api}/file/", headers=self._jwt_header,
                              data={
                                  'name': f_name,
-                                 'description': f_name,
+                                 'description': description,
                                  'directory': int(directory_id),
                                  'size': os.path.getsize(file_path),
                                  'replace': replace
@@ -49,6 +55,31 @@ class DatasetManager(Base):
             'uploaded': _uploaded,
         })
         data = {key: value for key, value in data.items() if key in ['uploaded', 'id', 'msg', 'path']}
+        
+        if lineage != None:
+            check.check_lists_int(data=lineage, dataName="lineage")
+            r = requests.post(f"{self._discovery_api}/file/{data['id']}/setLineage/", 
+                                headers=self._jwt_header,
+                                json={
+                                    'lineage': lineage
+                                }
+            )
+            try:
+                check.check_http_status_code(r)
+            except Exception as e:
+                data.update({
+                    'lineage_msg': str(e),
+                    'lineage': False
+                })
+            else:
+                data.update({
+                    'lineage': "created",
+                    'lineage': True
+                })
+            
+        
+        return data
+        
         return data
     
     def download_file(self, file_id=None, download_path=None):
